==> dl.php?src=linea21_1_3.zip: linea21/languages/fr/define.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage fr
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$l10n_links = array ('fr' => array(
    					'home'=> array ('linkvalue' => 'accueil', 'accesskey' => '1', 'title' => 'accueil', 'desc'=>'accéder à l\'accueil', 'alias'=> false, 'template'=>'home'),
    					'project'=> array ('linkvalue' => 'projet', 'accesskey' => 'a', 'title' => 'projets', 'desc'=>'les projets d\'action durable', 'alias'=> false, 'template'=>'publication'), 
    					'project-archives'=> array ('linkvalue' => 'projet-archives', 'title' => 'projets', 'desc'=>'les projets d\'action durable', 'alias'=> 'project', 'template'=>'publication'), 
    					'news'=> array ('linkvalue' => 'actualite', 'accesskey' => 'n', 'title' => 'actualités', 'desc'=>'l\'actualité de votre commune', 'alias'=> false, 'template'=>'publication'), 
    					'news-archives'=> array ('linkvalue' => 'actualite-archives', 'title' => 'actualités - archives', 'desc'=>'les archives de l\'actualité de votre commune', 'alias'=> 'news', 'template'=>'publication'),
    					'report'=> array ('linkvalue' => 'rapport', 'title' => 'rapports de groupes de travail', 'desc'=>'voir le rapport du groupe de travail', 'alias'=> 'workgroup', 'template'=>'publication'),
    					'report-part'=> array ('linkvalue' => 'rapport-partie', 'title' => 'détail rapport de groupe de travail', 'desc'=>'voir la partie du rapport du groupe de travail', 'alias'=> 'workgroup', 'template'=>'publication'),
    					'directory'=> array ('linkvalue' => 'annuaire', 'accesskey' => 'y', 'title' => 'annuaire', 'desc'=>'annuaire des professionnels de l\'environnement/développement durable', 'alias'=> false, 'template'=>'yellowpages'),
    					'directory-detail'=> array ('linkvalue' => 'annuaire-detail', 'title' => 'annuaire', 'desc'=>'annuaire des professionnels de l\'environnement/développement durable', 'alias'=> 'directory', 'template'=>'yellowpages'),
    					'directory-add'=> array ('linkvalue' => 'annuaire-ajout', 'title' => 'annuaire', 'desc'=>'annuaire des professionnels de l\'environnement/développement durable', 'alias'=> 'directory', 'template'=>'yellowpages'),
    					'workgroup'=> array ('linkvalue' => 'groupe-de-travail', 'accesskey' => 'w', 'title' => 'groupes de travail', 'desc'=>'accéder et participer aux groupes de travails', 'alias'=> false, 'template'=>'workshop'), 
    					'subscribe-workgroup'=> array ('linkvalue' => 'inscription-groupe-de-travail', 'title' => 'groupes de travail', 'desc'=>'s\'inscrire à un groupe de travail', 'alias'=> 'workgroup', 'template'=>'workshop'), 
    					'calendar'=> array ('linkvalue' => 'calendrier', 'title' => 'calendrier du groupe de travail', 'desc'=>'calendrier du groupe de travail', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic-list'=> array ('linkvalue' => 'liste-discussions', 'title' => 'discussions du groupe de travail', 'desc'=>'discussions du groupe de travail', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic'=> array ('linkvalue' => 'discussion', 'title' => 'discussion du groupe de travail', 'desc'=>'discussion du groupe de travail', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'post-update'=> array ('linkvalue' => 'edition-message', 'title' => 'édition de message', 'desc'=>'édition de message', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic-add'=> array ('linkvalue' => 'ajout-discussion', 'title' => 'ajout d\'une discussion au groupe de travail', 'desc'=>'ajout d\'une discussion au groupe de travail', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'post-add'=> array ('linkvalue' => 'ajout-message', 'title' => 'ajout de message', 'desc'=>'ajout de message', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'publication'=> array ('linkvalue' => 'dossier', 'accesskey' => 'p', 'title' => 'dossiers', 'desc'=>'accéder aux dossiers thématiques', 'alias'=> false, 'template'=>'publication'),
    					'publication-archives'=> array ('linkvalue' => 'dossier-archives', 'title' => 'dossiers', 'desc'=>'accéder aux archives des dossiers thématiques', 'alias'=> 'publication', 'template'=>'publication'),
    					'publication-part'=> array ('linkvalue' => 'dossier-partie', 'title' => 'dossiers', 'desc'=>'accéder en détail au dossier thématique', 'alias'=> 'publication', 'template'=>'publication'),
    					'dashboard'=> array ('linkvalue' => 'tableau-de-bord-idd', 'accesskey' => 'd', 'title' => 'tableau de bord IDD', 'desc'=>'l\'état des indicateurs en direct', 'alias'=> false, 'template'=>'dashboard'),  
                        'dashboard-rules'=> array ('linkvalue' => 'tableau-de-bord-idd-reglementation', 'title' => 'réglementation d\'un indicateur', 'desc'=>'réglementation d\'un indicateur', 'alias'=> 'dashboard', 'template'=>'dashboard'),  
                        'dashboard-assessment'=> array ('linkvalue' => 'tableau-de-bord-idd-evaluation', 'title' => 'critères d\'évaluation', 'desc'=>'critères d\'évaluation', 'alias'=> 'dashboard', 'template'=>'dashboard'),  
                        'dashboard-provider'=> array ('linkvalue' => 'tableau-de-bord-idd-fournisseur', 'title' => 'fournisseur d\'un indicateur', 'desc'=>'fournisseur d\'un indicateur', 'alias'=> 'dashboard', 'template'=>'dashboard'),
    					'user-prefs'=> array ('linkvalue' => 'prefs-utilisateur', 'accesskey' => 'u', 'title' => 'préférences utilisateurs', 'desc'=>'accéder à vos préférences utilisateurs', 'alias'=> false, 'template'=>'user'),
    					'logout'=> array ('linkvalue' => 'deconnexion', 'accesskey' => 'l','title' => 'se déconnecter', 'desc'=>'se déconnecter', 'alias'=> false, 'template'=>'user'),
    					'user-registration'=> array ('linkvalue' => 'inscription-utilisateur', 'accesskey' => 'c', 'title' => 'inscription utilisateur', 'desc'=>'créer mon compte', 'alias'=> 'user-prefs', 'template'=>'user'),
    					'user-profile'=> array ('linkvalue' => 'profil-utilisateur', 'title' => 'profil utilisateur', 'desc'=>'voir le profil utilisateur', 'alias'=> 'user-prefs', 'template'=>'user'),
    					'search'=> array ('linkvalue' => 'recherche', 'accesskey' => '4', 'title' => 'effectuer une recherche avancée', 'desc'=>'recherche avancée', 'alias'=> false, 'template'=>'search'),
    					'search-result'=> array ('linkvalue' => 'resultats-recherche', 'title' => 'résultats de la recherche', 'desc'=>'résultats de la recherche', 'alias'=> 'search', 'template'=>'search'),
    					'accessibility'=> array ('linkvalue' => 'accessibilite', 'accesskey' => '0', 'title' => 'Charte d\'accessibilité Linea21', 'desc'=>'Charte d\'accessibilité Linea21', 'alias'=> false, 'template'=>'accessibility'),
    					'report-all'=> array ('linkvalue' => 'listerapport', 'title' => 'rapports du groupe de travail', 'desc'=>'rapports du groupe de travail', 'alias'=> 'workgroup', 'template'=>'workshop'),  
                        'user-all'=> array ('linkvalue' => 'listeutilisateur', 'title' => 'utilisateurs du groupe de travail', 'desc'=>'utilisateurs du groupe de travail', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'subscribe-newsletter'=> array ('linkvalue' => 'abonnement-newsletter', 'title' => 's\'abonner à la newsletter', 'desc'=>'s\'abonner à la newsletter', 'alias'=> false, 'template'=>'message'),
    					'css-switch'=> array ('linkvalue' => 'changer-de-style', 'title' => 'changer-de-style et mise en page', 'desc'=>'changer-de-style et mise en page', 'alias'=> false, 'template'=>'message')
));

$l10n_filters = array ('fr' => array(
    						'level' => array('linkvalue' => 'niveau', 'name' => 'niveau', 'desc'=>'filtrer par niveau', 'active' => 0),
    						'theme' => array('linkvalue' => 'theme', 'name' => 'thème', 'desc'=>'filtrer par thème', 'active' => 0),
                        	'priority' => array('linkvalue' => 'priorite', 'name' => 'priorité', 'desc'=>'filtrer par priorité', 'active' => 0),
    						'scale' => array('linkvalue' => 'echelle', 'name' => 'échelle', 'desc'=>'filtrer par échelle', 'active' => 0),
                            'alpha' => array('linkvalue' => 'alpha', 'name' => 'alpha', 'desc'=>'filtrer par ordre alphabétique', 'active' => 0)
));
?>

==> dl.php?src=linea21_1_4.zip: linea21/languages/fr/define.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage fr
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

$culture = array( 'fr' => array( 'Language' => 'Français'));

$l10n_links = array ('fr' => array(
    					'home'=> array ('linkvalue' => 'accueil', 'accesskey' => '1', 'title' => 'accueil', 'desc'=>'accéder à l\'accueil', 'alias'=> false, 'template'=>'home'),
    					'project'=> array ('linkvalue' => 'projet', 'accesskey' => 'a', 'title' => 'projets', 'desc'=>'les projets d\'action durable', 'alias'=> false, 'template'=>'publication'),
    					'project-archives'=> array ('linkvalue' => 'projet-archives', 'title' => 'projets', 'desc'=>'les projets d\'action durable', 'alias'=> 'project', 'template'=>'publication'),
    					'news'=> array ('linkvalue' => 'actualite', 'accesskey' => 'n', 'title' => 'actualités', 'desc'=>'l\'actualité de la démarche', 'alias'=> false, 'template'=>'publication'),
    					'news-archives'=> array ('linkvalue' => 'actualite-archives', 'title' => 'actualités - archives', 'desc'=>'les archives de l\'actualité', 'alias'=> 'news', 'template'=>'publication'),
    					'report'=> array ('linkvalue' => 'rapport', 'title' => 'rapports de groupes de travail', 'desc'=>'voir le rapport du groupe de travail', 'alias'=> 'workgroup', 'template'=>'publication'),
    					'report-part'=> array ('linkvalue' => 'rapport-partie', 'title' => 'détail rapport de groupe de travail', 'desc'=>'voir la partie du rapport du groupe de travail', 'alias'=> 'workgroup', 'template'=>'publication'),
    					'directory'=> array ('linkvalue' => 'annuaire', 'accesskey' => 'y', 'title' => 'annuaire', 'desc'=>'annuaire des professionnels de l\'environnement/développement durable', 'alias'=> false, 'template'=>'yellowpages'),
    					'directory-detail'=> array ('linkvalue' => 'annuaire-detail', 'title' => 'annuaire', 'desc'=>'annuaire des professionnels de l\'environnement/développement durable', 'alias'=> 'directory', 'template'=>'yellowpages'),
    					'directory-add'=> array ('linkvalue' => 'annuaire-ajout', 'title' => 'annuaire', 'desc'=>'annuaire des professionnels de l\'environnement/développement durable', 'alias'=> 'directory', 'template'=>'yellowpages'),
    					'workgroup'=> array ('linkvalue' => 'groupe-de-travail', 'accesskey' => 'w', 'title' => 'groupes de travail', 'desc'=>'accéder et participer aux groupes de travails', 'alias'=> false, 'template'=>'workshop'),
    					'workgroup-subscription'=> array ('linkvalue' => 'inscription-groupe',  'accesskey' => 'a', 'title' => 'Devenir participant', 'desc'=>'s\'inscrire au(x) groupe(s) de travail', 'alias'=> false, 'template'=>'wg-subscription'),
    					'files'=> array ('linkvalue' => 'fichiers-partages', 'title' => 'Accéder aux fichiers', 'desc'=>'Accéder aux fichiers', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'calendar'=> array ('linkvalue' => 'calendrier', 'title' => 'calendrier du groupe de travail', 'desc'=>'calendrier du groupe de travail', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic-list'=> array ('linkvalue' => 'liste-discussions', 'title' => 'discussions du groupe de travail', 'desc'=>'discussions du groupe de travail', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic'=> array ('linkvalue' => 'discussion', 'title' => 'discussion du groupe de travail', 'desc'=>'discussion du groupe de travail', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'post-update'=> array ('linkvalue' => 'edition-message', 'title' => 'édition de message', 'desc'=>'édition de message', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'topic-add'=> array ('linkvalue' => 'ajout-discussion', 'title' => 'ajout d\'une discussion au groupe de travail', 'desc'=>'ajout d\'une discussion au groupe de travail', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'post-add'=> array ('linkvalue' => 'ajout-message', 'title' => 'ajout de message', 'desc'=>'ajout de message', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'publication'=> array ('linkvalue' => 'dossier', 'accesskey' => 'p', 'title' => 'dossiers', 'desc'=>'accéder aux dossiers thématiques', 'alias'=> false, 'template'=>'publication'),
    					'publication-archives'=> array ('linkvalue' => 'dossier-archives', 'title' => 'dossiers', 'desc'=>'accéder aux archives des dossiers thématiques', 'alias'=> 'publication', 'template'=>'publication'),
    					'publication-part'=> array ('linkvalue' => 'dossier-partie', 'title' => 'dossiers', 'desc'=>'accéder en détail au dossier thématique', 'alias'=> 'publication', 'template'=>'publication'),
    					'dashboard'=> array ('linkvalue' => 'tableau-de-bord-idd', 'accesskey' => 'd', 'title' => 'tableau de bord IDD', 'desc'=>'l\'état des indicateurs en direct', 'alias'=> false, 'template'=>'dashboard'),
                        'dashboard-rules'=> array ('linkvalue' => 'tableau-de-bord-idd-reglementation', 'title' => 'réglementation d\'un indicateur', 'desc'=>'réglementation d\'un indicateur', 'alias'=> 'dashboard', 'template'=>'dashboard'),
                        'dashboard-assessment'=> array ('linkvalue' => 'tableau-de-bord-idd-evaluation', 'title' => 'critères d\'évaluation', 'desc'=>'critères d\'évaluation', 'alias'=> 'dashboard', 'template'=>'dashboard'),
                        'dashboard-provider'=> array ('linkvalue' => 'tableau-de-bord-idd-fournisseur', 'title' => 'fournisseur d\'un indicateur', 'desc'=>'fournisseur d\'un indicateur', 'alias'=> 'dashboard', 'template'=>'dashboard'),
    					'user-prefs'=> array ('linkvalue' => 'prefs-utilisateur', 'accesskey' => 'u', 'title' => 'préférences utilisateurs', 'desc'=>'accéder à vos préférences utilisateurs', 'alias'=> false, 'template'=>'user'),
    					'logout'=> array ('linkvalue' => 'deconnexion', 'accesskey' => 'l','title' => 'se déconnecter', 'desc'=>'se déconnecter', 'alias'=> false, 'template'=>'user'),
    					'user-registration'=> array ('linkvalue' => 'inscription-utilisateur', 'accesskey' => 'c', 'title' => 'inscription utilisateur', 'desc'=>'créer mon compte', 'alias'=> 'user-prefs', 'template'=>'user'),
    					'user-profile'=> array ('linkvalue' => 'profil-utilisateur', 'title' => 'profil utilisateur', 'desc'=>'voir le profil utilisateur', 'alias'=> 'user-prefs', 'template'=>'user'),
    					'forgot-password'=> array ('linkvalue' => 'mot-de-passe-oublie', 'title' => 'Vous avez oublié votre mot de passe?', 'desc'=>'Changer votre mot de passe', 'alias'=> 'user-prefs', 'template'=>'user'),
    					'search'=> array ('linkvalue' => 'recherche', 'accesskey' => '4', 'title' => 'effectuer une recherche avancée', 'desc'=>'recherche avancée', 'alias'=> false, 'template'=>'search'),
    					'search-result'=> array ('linkvalue' => 'resultats-recherche', 'title' => 'résultats de la recherche', 'desc'=>'résultats de la recherche', 'alias'=> 'search', 'template'=>'search'),
    					'accessibility'=> array ('linkvalue' => 'accessibilite', 'accesskey' => '0', 'title' => 'Charte d\'accessibilité Linea21', 'desc'=>'Charte d\'accessibilité Linea21', 'alias'=> false, 'template'=>'accessibility'),
    					'report-all'=> array ('linkvalue' => 'listerapport', 'title' => 'rapports du groupe de travail', 'desc'=>'rapports du groupe de travail', 'alias'=> 'workgroup', 'template'=>'workshop'),
                        'user-all'=> array ('linkvalue' => 'listeutilisateur', 'title' => 'utilisateurs du groupe de travail', 'desc'=>'utilisateurs du groupe de travail', 'alias'=> 'workgroup', 'template'=>'workshop'),
    					'subscribe-newsletter'=> array ('linkvalue' => 'abonnement-newsletter', 'title' => 's\'abonner à la newsletter', 'desc'=>'s\'abonner à la newsletter', 'alias'=> false, 'template'=>'message'),
    					'css-switch'=> array ('linkvalue' => 'changer-de-style', 'title' => 'changer-de-style et mise en page', 'desc'=>'changer-de-style et mise en page', 'alias'=> false, 'template'=>'message'),
    					'contact'=> array ('linkvalue' => 'contact', 'accesskey' => 'z', 'title' => 'contact', 'desc'=>'accéder au formulaire de contact', 'alias'=> false, 'template'=>'message')


));

$l10n_filters = array ('fr' => array(
    						'level' => array('linkvalue' => 'niveau', 'name' => 'niveau', 'desc'=>'filtrer par niveau', 'active' => 0),
    						'theme' => array('linkvalue' => 'theme', 'name' => 'thème', 'desc'=>'filtrer par thème', 'active' => 0),
                        	'priority' => array('linkvalue' => 'priorite', 'name' => 'priorité', 'desc'=>'filtrer par priorité', 'active' => 0),
    						'scale' => array('linkvalue' => 'echelle', 'name' => 'échelle', 'desc'=>'filtrer par échelle', 'active' => 0),
                            'alpha' => array('linkvalue' => 'alpha', 'name' => 'alpha', 'desc'=>'filtrer par ordre alphabétique', 'active' => 0)
));
?>
